import { Component, Injectable } from '@angular/core';
import { NgbTimeStruct, NgbTimeAdapter, NgbTimepickerModule } from '@ng-bootstrap/ng-bootstrap';
import { FormsModule } from '@angular/forms';

const pad = (i: number): string => (i < 10 ? `0${i}` : `${i}`);

/**
 * Example of a String Time adapter
 */
@Injectable()
export class NgbTimeStringAdapter extends NgbTimeAdapter<string> {
	fromModel(value: string | null): NgbTimeStruct | null {
		if (!value) {
			return null;
		}
		const split = value.split(':');
		return {
			hour: parseInt(split[0], 10),
			minute: parseInt(split[1], 10),
			second: parseInt(split[2], 10),
		};
	}

	toModel(time: NgbTimeStruct | null): string | null {
		return time != null ? `${pad(time.hour)}:${pad(time.minute)}:${pad(time.second)}` : null;
	}
}

@Component({
	selector: 'ngbd-timepicker-adapter',
	standalone: true,
	imports: [NgbTimepickerModule, FormsModule],
	templateUrl: './timepicker-adapter.html',
	// NOTE: For this example we are only providing current component, but probably
	// NOTE: you will want to provide your main App Module
	providers: [{ provide: NgbTimeAdapter, useClass: NgbTimeStringAdapter }],
})
export class NgbdTimepickerAdapter {
	time: '13:30:00';
}
